.stats-container {
    display: flex;
    flex-wrap: wrap;
    width: 100%;
    justify-content: space-between;
    gap: 20px;
    margin-top: 20px;
    margin-bottom: 20px;
}

.stats-box {
    flex: 1;
    min-width: 300px;
    max-width: 100%;
}

.stats-table {
    width: 100%;
    height: 20vh;
    border-collapse: collapse;
}

.stats-table th, .stats-table td {
    border: 1px solid #ddd;
    padding: 8px;
}

.stats-table th {
    background-color: #f4f4f4;
}