# Generated by Django 4.2.19 on 2025-03-22 16:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_logbox", "0004_alter_serverlog_client_ip_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="serverlog",
            options={
                "ordering": ("-timestamp",),
                "verbose_name": "Server Log",
                "verbose_name_plural": "Server Logs",
            },
        ),
        migrations.AddField(
            model_name="serverlog",
            name="browser",
            field=models.CharField(
                blank=True,
                help_text="Browser data parsed from User-Agent request header.",
                max_length=255,
                null=True,
                verbose_name="browser",
            ),
        ),
        migrations.AddField(
            model_name="serverlog",
            name="device",
            field=models.CharField(
                blank=True,
                help_text="Device data parsed from User-Agent request header.",
                max_length=255,
                null=True,
                verbose_name="device",
            ),
        ),
        migrations.AddField(
            model_name="serverlog",
            name="os",
            field=models.CharField(
                blank=True,
                help_text="OS data parsed from User-Agent request header.",
                max_length=255,
                null=True,
                verbose_name="os",
            ),
        ),
        migrations.AlterField(
            model_name="serverlog",
            name="user_agent",
            field=models.TextField(
                help_text="User-Agent string from the client's request header, providing browser and OS details.",
                max_length=255,
                null=True,
                verbose_name="user_agent",
            ),
        ),
    ]
