# Generated by Django 5.1.1 on 2024-10-07 14:02

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("django_logbox", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="serverlog",
            name="duration",
        ),
    ]
